function [logL, prior]=Lhood_WRI(par,tC,tS,NC,NS,C,S)
%
% [logL, prior]=Lhood_WRI(par,tC,tS,NC,NS,C,S)
%
% Matlab function to compute the log likelihood for the number of reportd
% holdings with Schmallenberg virus in each region (at NUTS2 region level)
%
% Inputs:
% par - array containing model parameters
% tC, tS - cumulative vector activity for each region
% NC, NS - number of cattle or sheep farms reporting during each time
%          period for each region
% C, S - number of cattle or sheep holdings in each region
%
% Outputs:
% logL - log likelihood for parameters
% prior - log(joint prior) for parameters

%==========================================================================
% PREPARE THE INPUTS
% Determine the number of regions reporting holdings with cases in cattle
% or sheep
ncattle=length(NC);
nsheep=length(NS);

% Back-transform the parameters
lambdaC=exp(par(1:ncattle));
lambdaS=exp(par(ncattle+1:ncattle+nsheep));
mu_lambdaC=exp(par(ncattle+nsheep+1));
k_lambdaC=exp(par(ncattle+nsheep+2));
mu_lambdaS=exp(par(ncattle+nsheep+3));
k_lambdaS=exp(par(ncattle+nsheep+4));
%==========================================================================

%==========================================================================
% COMPUTE THE JOINT PRIOR
% Assume hierarchical structure for the within-region forces of infection
prior=sum(log(gampdf(lambdaC,k_lambdaC,mu_lambdaC/k_lambdaC)))+...
      sum(log(gampdf(lambdaS,k_lambdaS,mu_lambdaS/k_lambdaS)));
  
% Assume non-informative priors for the hierarchical parameters
prior=prior+log(gampdf(mu_lambdaC,1,100))+...
            log(gampdf(k_lambdaC,1,100))+...
            log(gampdf(mu_lambdaS,1,100))+...
            log(gampdf(k_lambdaS,1,100));
%==========================================================================

%==========================================================================
% COMPUTE THE LOG LIKELIHOOD
% Compute the expected number of affected cattle and sheep holdings in each
% region
muC=lambdaC.*C.*tC;
muS=lambdaS.*S.*tS;

% Compute the log likelihood for the reported holdings
logL=sum(log(poisspdf(NC,muC)))+sum(log(poisspdf(NS,muS)));
%==========================================================================
