function ModelCheckingBRT(kflag,nreps)

% Matlab function to run a bunch of replicates of the SBV model for the
% purposes of model checking
%
% Inputs:
% kflag - flag indicating kernel to use
% nreps - number of replicates of model to run

% Initialise the random number generator
stream=RandStream('mt19937ar','Seed',round(sum(1000*clock)));
RandStream.setGlobalStream(stream);

%==========================================================================
% PREPARE THE DATA
% Load the data
varload=load('SBVInEurope_DataForBRTModel');

% Extract the relevant bits
D=varload.D;
nfarm=varload.nfarm;
IObs=varload.I;

% Extract the initial conditions
t0=find(sum(IObs,1)>0,1,'first');
I0=IObs(:,t0);
%==========================================================================

%==========================================================================
% LOAD THE PARAMETER ESTIMATES
% Load the parameters for transmission between regions
varload=load(['ParameterMCMCSamples_BRTKernel' num2str(kflag)]);

% Back-transform the sampled parameters          
h0=[];
a=[];
d0=[];
for c=1:length(varload.ParSamp),
    h0=[h0; exp(varload.ParSamp{c}(:,1))];
    a=[a; exp(varload.ParSamp{c}(:,2))];
    if kflag<=2,
        d0=[d0; exp(varload.ParSamp{c}(:,3))];
    end
end

% Create a dummy array for d0 if kflag>2 (the parameter is not used in
% this case)
if kflag>=3,
    d0=zeros(size(h0));
end
%==========================================================================

%==========================================================================
% SIMULATE THE REPLICATES
% Set the number of days for which to run the model
tstop=365;

% Create cell arrays to store the outputs for each replicate
I=cell(nreps,1);

% Draw samples from the posterior density
u=unidrnd(length(h0),nreps,1);

% Run each replicate
for rep=1:nreps,
    display(['Simulating replicate: ' num2str(rep)])
    I{rep}=SimulateBRT(t0,tstop,I0,kflag,nfarm,D,...
                       h0(u(rep)),a(u(rep)),d0(u(rep)));
end

% Save the output
save(['PosteriorModelChecking_BRTKernel' num2str(kflag)],'I')
%==========================================================================
